from .datastorage import DataStorage

from .filesystem import Filesystem
from .hdfs import Hdfs
from .hive import Hive
from .presto import Presto

from .model import ModelStorage
from .model import minio, filesystem, hdfs